@@ -49,7 +49,7 @@ class Client:
     def smart_put_object(self, key, data, content_type=None, headers={}, **kwargs):
         if isinstance(data, (dict, list)):
             content_type = "application/json"
-            data = json.dumps(data)
+            data = json.dumps(data, ensure_ascii=False)
         if isinstance(data, str):
             data = data.encode("utf-8")
         gzip_data = gzip.compress(data)
